#!/usr/local/sbin/charm-env python3

import os
import sys
import traceback

hooks_dir = os.path.abspath(os.path.join(os.path.dirname(__file__),
                                         '..', 'hooks'))
if hooks_dir not in sys.path:
    sys.path.append(hooks_dir)
libs_dir = os.path.abspath(os.path.join(os.path.dirname(__file__),
                                        '..', 'lib'))
if libs_dir not in sys.path:
    sys.path.append(libs_dir)

from charms import reactive  # noqa E402
from charmhelpers.core import hookenv, host, unitdata  # noqa E402


def reactive_remove_state(state):
    reactive.remove_state(state)
    reactive.main()


def get_admin_passwd():
    db = unitdata.kv()
    admin_password = db.get('admin_password')
    if not admin_password:
        admin_password = host.pwgen(18)
        db.set('admin_password', admin_password)
        reactive_remove_state('graylog.configured')
    hookenv.action_set({'admin-password': admin_password})


def set_admin_passwd(admin_password=None):
    db = unitdata.kv()
    stored_password = db.get('admin_password')
    if admin_password == stored_password:
        status = 'no-change'
    else:
        if admin_password and admin_password != 'None':
            status = 'updated'
        else:
            status = 'generated'
            admin_password = host.pwgen(18)
        db.set('admin_password', admin_password)

    hookenv.action_set({'admin-password': admin_password, 'change': status})
    reactive_remove_state('graylog.configured')


def main(argv):
    action = os.path.basename(argv[0])
    params = hookenv.action_get()
    try:
        if action == 'show-admin-password':
            get_admin_passwd()
        elif action == 'set-admin-password':
            set_admin_passwd(params['password'])
        else:
            hookenv.action_fail('Action {} not implemented'.format(action))
    except Exception:
        hookenv.action_fail('Unhandled exception')
        tb = traceback.format_exc()
        hookenv.action_set(dict(traceback=tb))
        hookenv.log('Unhandled exception in action {}'.format(action))
        print(tb)


if __name__ == '__main__':
    main(sys.argv)
