from charmhelpers.core import hookenv
from charms.layer import snap

SNAP_NAME = 'graylog'


def get_api_port():
    return '9001' if is_v2() else '9000'


def get_api_url():
    return 'http://127.0.0.1:{}/api/'.format(get_api_port())


def is_v2():
    version = snap.get_installed_version(SNAP_NAME)
    # If the snap isn't installed yet, base our version off the charm config
    if not version:
        version = hookenv.config('channel')
    return True if version.startswith('2') else False


def validate_api_uri(uri):
    """Ensure the given API URI is valid based on the Graylog version.

    For v2, api-related options should end with '/api/'. In v3, the graylog
    server hard codes '/api/' to the end of these options and should therefore
    be removed if included in the charm config.
    """
    if not uri.endswith('/'):
        uri += '/'

    if is_v2():
        if not uri.endswith('/api/'):
            hookenv.log("Appending 'api/' to the configured REST API options")
            uri += 'api/'
    else:
        if uri.endswith('/api/'):
            hookenv.log("Removing 'api/' from the configurted REST API options")
            uri = uri[:-4]

    return uri
