import unittest
from unittest import mock

from charms.layer.graylog import (
    get_api_port,
    get_api_url,
    validate_api_uri,
)


class TestLibraryUtils(unittest.TestCase):
    """Test lib.charms.layer.graylog utils."""

    @mock.patch('charms.layer.graylog.snap.get_installed_version')
    def test_api(self, mock_snap):
        """Validate the api port/url match what we expect for v2 and v3."""
        mock_snap.return_value = '2.foo'
        self.assertEqual(get_api_port(), '9001')
        self.assertEqual(get_api_url(), 'http://127.0.0.1:9001/api/')

        mock_snap.return_value = '3.bar'
        self.assertEqual(get_api_port(), '9000')
        self.assertEqual(get_api_url(), 'http://127.0.0.1:9000/api/')

    @mock.patch('charms.layer.graylog.snap.get_installed_version')
    def test_validate_api_url(self, mock_snap):
        """Validate the URI suffix is valid for v2 and v3."""
        mock_snap.return_value = '2.foo'
        self.assertEqual(validate_api_uri('foo'), 'foo/api/')
        self.assertEqual(validate_api_uri('foo/'), 'foo/api/')
        self.assertEqual(validate_api_uri('foo/api'), 'foo/api/')

        mock_snap.return_value = '3.bar'
        self.assertEqual(validate_api_uri('foo'), 'foo/')
        self.assertEqual(validate_api_uri('foo/'), 'foo/')
        self.assertEqual(validate_api_uri('foo/api/'), 'foo/')
